unit udata;

{$mode objfpc}{$H+}

interface

uses
  Classes, SysUtils, IniFiles, dateutils;

type
  TItem = record
    HasRegel : boolean;
    Staerke,
    Schmerz,
    Medizin,
    Dosis    : string;
  end;

  TRegel = class
  private
    FFilename, FPath, FExt: string;
    FYear: integer;
    Items: array[1..31, 1..12] of TItem;
    procedure SetYear(AValue: integer);
    function GetHasRegel(xy: TPoint): boolean;
    procedure SetHasRegel(xy: TPoint; AValue: boolean);
    function GetItem(xy: TPoint): TItem;
    procedure SetItem(xy: TPoint; AValue: TItem);
  public
    constructor Create;
    destructor Done;
    function Lastday(Month: integer): integer;
    property Year: integer read FYear write SetYear;
    property HasRegel[xy: TPoint]: boolean read GetHasRegel write SetHasRegel; default;
    property Item[xy: TPoint]: TItem read GetItem write SetItem;
  end;

implementation

constructor TRegel.Create;
begin
  inherited;
  FPath := ExtractFilePath(GetAppConfigFile(false));
  Fext := 'regel';
  SetYear(YearOf(Date));
end;

destructor TRegel.Done;
begin
  inherited;
end;

function TRegel.Lastday(Month: integer): integer;
begin
  Result := DaysInAMonth(FYear, Month);
end;

procedure TRegel.SetYear(AValue: integer);
var
  d, m: integer;
  s: string;
begin
  FYear := AValue;
  FFilename := Format('%s%d.%s', [FPath, FYear, FExt]);
  if FileExists(FFilename) then begin
    // Daten laden
     with TIniFile.Create(FFilename) do try
       for m := 1 to 12 do begin
         for d := 1 to 31 do begin
           s := Format('%.2d-%.2d', [m, d]);
           Items[d, m].HasRegel := ReadBool(s, 'HasRegel', false);
           Items[d, m].Staerke := ReadString(s, 'Staerke', '');
           Items[d, m].Schmerz := ReadString(s, 'Schmerz', '');
           Items[d, m].Medizin := ReadString(s, 'Medizin', '');
           Items[d, m].Dosis := ReadString(s, 'Dosis', '');
         end;
       end;
     finally
       Free;
     end;
  end;
end;

function TRegel.GetHasRegel(xy: TPoint): boolean;
begin
  Result := Items[xy.x, xy.y].HasRegel;
end;

procedure TRegel.SetHasRegel(xy: TPoint; AValue: boolean);
begin
  Items[xy.x, xy.y].HasRegel := AValue;
end;

function TRegel.GetItem(xy: TPoint): TItem;
begin
  Result := Items[xy.x, xy.y];
end;

procedure TRegel.SetItem(xy: TPoint; AValue: TItem);
var
  d, m: integer;
  s: string;
begin
  Items[xy.x, xy.y] := AValue;
  if FFilename <> '' then begin
    // Daten speichern
    if FileExists(FFilename) then DeleteFile(FFilename);
    with TIniFile.Create(FFilename) do try
      for m := 1 to 12 do begin
        for d := 1 to 31 do begin
          s := Format('%.2d-%.2d', [m, d]);
          if Items[d, m].HasRegel then begin
            WriteBool(s, 'HasRegel', true);
            WriteString(s, 'Staerke', Items[d, m].Staerke);
            WriteString(s, 'Schmerz', Items[d, m].Schmerz);
            WriteString(s, 'Medizin', Items[d, m].Medizin);
            WriteString(s, 'Dosis', Items[d, m].Dosis);
          end;
        end;
      end;
    finally
      Free;
    end;
  end;
end;

end.

